@@ -4,6 +4,7 @@
  *
  * Copyright 2001, 2002 Sun Microsystems Inc.,
  * Copyright 2001, 2002 Ximian, Inc.
+ * Copyright 2010, 2011 Novell, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -36,7 +37,6 @@
 AtspiAccessible *
 atspi_table_get_caption (AtspiTable *obj, GError **error)
 {
-  char *path;
   AtspiAccessible *retval = NULL;
 
   g_return_val_if_fail (obj != NULL, NULL);
@@ -130,12 +130,11 @@ atspi_table_get_accessible_at (AtspiTable *obj,
                                  GError **error)
 {
   dbus_int32_t d_row = row, d_column = column;
-  AtspiAccessible *retval;
   DBusMessage *reply;
 
   g_return_val_if_fail (obj != NULL, NULL);
 
-  reply = _atspi_dbus_call_partial (obj, atspi_interface_table, "GetAccessibleAt", error, "ii", row, column);
+  reply = _atspi_dbus_call_partial (obj, atspi_interface_table, "GetAccessibleAt", error, "ii", d_row, d_column);
 
   return _atspi_dbus_return_accessible_from_message (reply);
 }
@@ -348,7 +347,7 @@ atspi_table_get_row_header (AtspiTable *obj,
 
   g_return_val_if_fail (obj != NULL, NULL);
 
-  reply = _atspi_dbus_call (obj, atspi_interface_table, "GetRowHeader", error, "i", d_row);
+  reply = _atspi_dbus_call_partial (obj, atspi_interface_table, "GetRowHeader", error, "i", d_row);
 
   return _atspi_dbus_return_accessible_from_message (reply);
 }
@@ -374,7 +373,7 @@ atspi_table_get_column_header (AtspiTable *obj,
 
   g_return_val_if_fail (obj != NULL, NULL);
 
-  reply = _atspi_dbus_call (obj, atspi_interface_table, "GetCoumnHeader", error, "i", &d_column);
+  reply = _atspi_dbus_call_partial (obj, atspi_interface_table, "GetColumnHeader", error, "i", &d_column);
 
   return _atspi_dbus_return_accessible_from_message (reply);
 }
