@@ -25,6 +25,8 @@
 #include <config.h>
 #include <string.h>
 #include <glib.h>
+#include <stdio.h>
+#include <dlfcn.h>
 
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
@@ -33,10 +35,14 @@
 #include "registry.h"
 #include "deviceeventcontroller.h"
 
-#if !defined ATSPI_INTROSPECTION_PATH
-    #error "No introspection XML directory defined"
+#ifdef RELOCATE
+#define DBUS_GCONF_KEY  "/desktop/gnome/interface/at-spi-dbus"
+#else
+#define CORBA_GCONF_KEY  "/desktop/gnome/interface/at-spi-corba"
 #endif
 
+static gboolean need_to_quit ();
+
 static GMainLoop *mainloop;
 static gchar *dbus_name = NULL;
 static gboolean use_gnome_session = FALSE;
@@ -265,7 +271,7 @@ spi_get_bus (void)
 	 else
          {
 	     if (!dbus_bus_register (bus, &error))
-	         g_error ("AT-SPI: Couldn't register with bus: %s\n");
+	         g_error ("AT-SPI: Couldn't register with bus: %s\n", error.message);
          } 
      }
 
@@ -274,12 +280,14 @@ spi_get_bus (void)
 
 /*---------------------------------------------------------------------------*/
 
+typedef GObject *(*gconf_client_get_default_t) ();
+typedef gboolean (*gconf_client_get_bool_t)(GObject *, const char *, void *);
+
 int
 main (int argc, char **argv)
 {
   SpiRegistry *registry;
   SpiDEController *dec;
-  gchar *introspection_directory;
 
   DBusConnection *bus = NULL;
 
@@ -289,10 +297,10 @@ main (int argc, char **argv)
   DBusError error;
   int ret;
 
-  g_type_init();
+  if (need_to_quit ())
+    return 0;
 
-  /* We depend on GDK as well as XLib for device event processing */
-  gdk_init(&argc, &argv);
+  g_type_init();
 
   /*Parse command options*/
   opt = g_option_context_new(NULL);
@@ -325,11 +333,6 @@ main (int argc, char **argv)
       g_print ("SpiRegistry daemon is running with well-known name - %s\n", dbus_name);
     }
 
-  /* Get D-Bus introspection directory */
-  introspection_directory = (char *) g_getenv("ATSPI_INTROSPECTION_PATH");
-  if (introspection_directory == NULL)
-      introspection_directory = ATSPI_INTROSPECTION_PATH;
-
   registry = spi_registry_new (bus);
   dec = spi_registry_dec_new (registry, bus);
 
@@ -345,3 +348,43 @@ main (int argc, char **argv)
   g_main_loop_run (mainloop);
   return 0;
 }
+
+static gboolean
+need_to_quit ()
+{
+  void *gconf = NULL;
+  gconf_client_get_default_t gconf_client_get_default = NULL;
+  gconf_client_get_bool_t gconf_client_get_bool = NULL;
+  GObject *gconf_client;	/* really a GConfClient */
+  gboolean ret;
+
+  g_type_init ();
+
+  gconf = dlopen ("libgconf-2.so", RTLD_LAZY);
+  if (gconf)
+    {
+      gconf_client_get_default = dlsym (gconf, "gconf_client_get_default");
+      gconf_client_get_bool = dlsym (gconf, "gconf_client_get_bool");
+  }
+
+  if (!gconf_client || !gconf_client_get_bool)
+    {
+      if (gconf)
+        dlclose (gconf);
+      return FALSE;
+    }
+
+  /* If we've been relocated, we will exit if the at-spi-corba gconf key
+ * has been set.  If we have not been relocated, we will only run if the
+ * at-spi-dbus gconf key has been set.
+   */
+  gconf_client = gconf_client_get_default ();
+#ifdef RELOCATE
+  ret = !gconf_client_get_bool (gconf_client, DBUS_GCONF_KEY, NULL);
+#else
+  ret = gconf_client_get_bool (gconf_client, CORBA_GCONF_KEY, NULL);
+#endif
+  g_object_unref (gconf_client);
+
+  return ret;
+}
